@@ -22,19 +22,19 @@ main (int argc, char* argv[])
 
   try
   {
-    auto_ptr<instance_type> inst (instance (argv[1]));
+    auto_ptr<instance> inst (instance_ (argv[1]));
 
-    instance_type copy (*inst); // Dynamic types are preserved in copies.
+    instance copy (*inst); // Dynamic types are preserved in copies.
 
     // Print what we've got.
     //
-    for (instance_type::person::const_iterator i (copy.person ().begin ());
+    for (instance::person::const_iterator i (copy.person ().begin ());
          i != copy.person ().end ();
          ++i)
     {
       cerr << i->name ();
 
-      if (const superman_type* s = dynamic_cast<const superman_type*> (&*i))
+      if (const superman* s = dynamic_cast<const superman*> (&*i))
       {
         if (s->can_fly ())
           cerr << ", flying superman";
@@ -50,7 +50,7 @@ main (int argc, char* argv[])
     xml_schema::namespace_infomap map;
     map[""].schema = "schema.xsd";
 
-    instance (std::cout, copy, map);
+    instance_ (std::cout, copy, map);
   }
   catch (const xml_schema::exception& e)
   {
